"""Init Admin Page"""
import logging

from django.contrib import admin
from django.http import HttpResponseRedirect
from django.shortcuts import render

from .forms import UserCreatorForm
from .models import Article, Medium, MediumType, ParentTag, Tag, Timeline, Overview, Files, User

# Custom Actions for the admin site
from .wizard.manipulators import create_users_in_db

logger = logging.getLogger(__name__)


class UserAdmin(admin.ModelAdmin):
    """ adding more actions to User in Admin sites """
    list_display = ['id_tag', 'activated']
    ordering = ['-activated']
    actions = ['deactivate_user', 'create_user']

    @admin.action(description='Deactivate Users')
    def deactivate_user(self, request, queryset):
        """ instead of deleting we deactivate user """
        queryset.update(activated=False)
        self.message_user(request, f"Deactivated {queryset.count()} users")

    @admin.action(description='Create Users')
    def create_user(self, request, queryset):
        """ you can create a specific count of users """
        if 'apply' in request.POST:
            form = UserCreatorForm(request.POST)
            if form.is_valid():
                user_count_ = form.cleaned_data['user_count']
                create_users_in_db(user_count_)
                self.message_user(request, f"Created {user_count_} users")
            return HttpResponseRedirect(request.get_full_path())
        form = UserCreatorForm(initial={'user_count': 1})
        return render(request, 'admin/create_user.html', context={'form': form, 'items': queryset})


# Register your models here.
admin.site.register(Article)
admin.site.register(Medium)
admin.site.register(MediumType)
admin.site.register(Tag)
admin.site.register(ParentTag)
admin.site.register(Timeline)
admin.site.register(Overview)
admin.site.register(Files)
admin.site.register(User, UserAdmin)  # Register Model with custom actions
