''' static assignments of regionality and meta tags '''
import enum


class MediaOverviewType(enum.Enum):
    ''' Defines possible MediaOverviewType for TopMediaView(APIView) '''
    ALLTAGS = "alltags"
    USERTAGS = "usertags"
    QUERYTAG = "querytag"


class MediaRegionality(enum.Enum):
    ''' Defines possible MediumTypes '''
    REGIONAL = "Regionales Medium"
    NATIONAL = "Überregionales Medium"
    WEBSITE = "Webseite"


# https://de.wikipedia.org/wiki/Liste_deutscher_Regionalzeitungen
media_regionality = {
    "abendzeitung münchen": MediaRegionality.REGIONAL,
    "altmark zeitung": MediaRegionality.REGIONAL,
    "antenne brandenburg": MediaRegionality.REGIONAL,
    "ard-mediathek": MediaRegionality.WEBSITE,
    "ärzte zeitung": MediaRegionality.NATIONAL,
    "ärzte zeitung online": MediaRegionality.WEBSITE,
    "augsburger allgemeine": MediaRegionality.REGIONAL,
    "badische neueste nachrichten baden-baden": MediaRegionality.REGIONAL,
    "badisches tagblatt baden-baden": MediaRegionality.REGIONAL,
    "badische zeitung": MediaRegionality.REGIONAL,
    "badische zeitung freiburg im breisgau": MediaRegionality.REGIONAL,
    "berliner morgenpost": MediaRegionality.REGIONAL,
    "berliner morgenpost online": MediaRegionality.WEBSITE,
    "berliner sonntagsblatt": MediaRegionality.REGIONAL,
    "berliner zeitung": MediaRegionality.REGIONAL,
    "berlinonline / berliner kurier": MediaRegionality.WEBSITE,
    "berlinonline / berliner zeitung": MediaRegionality.WEBSITE,
    "bild": MediaRegionality.NATIONAL,
    "bild der frau": MediaRegionality.NATIONAL,
    "blickpunkt brandenburg": MediaRegionality.REGIONAL,
    "blickpunkt (brandenburg)": MediaRegionality.REGIONAL,
    "bundeswehr-journal": MediaRegionality.NATIONAL,
    "b.z.": MediaRegionality.REGIONAL,
    "capital": MediaRegionality.NATIONAL,
    "cicero": MediaRegionality.NATIONAL,
    "der freitag": MediaRegionality.NATIONAL,
    "der prignitzer": MediaRegionality.REGIONAL,
    "der spiegel": MediaRegionality.NATIONAL,
    "der tagesspiegel": MediaRegionality.REGIONAL,
    "deutschlandfunk kultur": MediaRegionality.WEBSITE,
    "deutscher bundeswehr-verband": MediaRegionality.NATIONAL,
    "die rheinpfalz - ludwigshafener rundschau": MediaRegionality.REGIONAL,
    "die tageszeitung": MediaRegionality.NATIONAL,
    "die welt": MediaRegionality.NATIONAL,
    "die zeit": MediaRegionality.NATIONAL,
    "dw deutsche welle": MediaRegionality.NATIONAL,
    "euro am sonntag": MediaRegionality.NATIONAL,
    "focus": MediaRegionality.NATIONAL,
    "focus online": MediaRegionality.WEBSITE,
    "frankfurter allgemeine sonntagszeitung": MediaRegionality.NATIONAL,
    "frankfurter allgemeine zeitung": MediaRegionality.NATIONAL,
    "frankfurter rundschau": MediaRegionality.NATIONAL,  # erscheint in 1x Stadt-, 1x Deutschland-, sowie 3x Regionalausgaben
    "freisinger tagblatt": MediaRegionality.REGIONAL,
    "göttinger tageblatt": MediaRegionality.REGIONAL,
    "gransee-zeitung": MediaRegionality.REGIONAL,
    "handelsblatt": MediaRegionality.NATIONAL,
    "handelsblatt sonderhefte": MediaRegionality.NATIONAL,
    "hannoversche allgemeine zeitung": MediaRegionality.REGIONAL,
    "hamburger abendblatt": MediaRegionality.REGIONAL,
    "hamburger abendblatt - pinneberg": MediaRegionality.REGIONAL,
    "hessische allgemeine": MediaRegionality.REGIONAL,
    "idw-online (informationsdienst wissenschaft)": MediaRegionality.WEBSITE,
    "inforardio rbb": MediaRegionality.REGIONAL,
    "jüdische allgemeine": MediaRegionality.NATIONAL,
    "junge welt": MediaRegionality.NATIONAL,
    "kieler nachrichten - kieler zeitung": MediaRegionality.REGIONAL,
    "kreiszeitung (syke)": MediaRegionality.REGIONAL,
    "lausitzer rundschau": MediaRegionality.REGIONAL,
    "leipziger volkszeitung": MediaRegionality.REGIONAL,
    "lübecker nachrichten": MediaRegionality.REGIONAL,
    "lvz online (leipziger volkszeitung)": MediaRegionality.WEBSITE,
    "manager magazin": MediaRegionality.NATIONAL,
    "mannheimer morgen": MediaRegionality.REGIONAL,
    "märkische allgemeine": MediaRegionality.REGIONAL,
    "märkische oderzeitung": MediaRegionality.REGIONAL,
    "morgenweb (mannheimer morgen)": MediaRegionality.WEBSITE,
    "mündener allgemeine": MediaRegionality.REGIONAL,
    "nd online (neues deutschland)": MediaRegionality.WEBSITE,
    "neues deutschland": MediaRegionality.NATIONAL,
    "neue presse": MediaRegionality.REGIONAL,
    "nordkurier": MediaRegionality.REGIONAL,
    "nordsee-zeitung": MediaRegionality.REGIONAL,
    "nordwest-zeitung": MediaRegionality.REGIONAL,
    "northeimer neueste nachrichten": MediaRegionality.REGIONAL,
    "offenbach-post": MediaRegionality.REGIONAL,
    "oranienburger generalanzeiger": MediaRegionality.REGIONAL,
    "ostsee-zeitung": MediaRegionality.REGIONAL,
    "potsdamer neueste nachrichten": MediaRegionality.REGIONAL,
    "prignitz express": MediaRegionality.REGIONAL,
    "rbb mediathek": MediaRegionality.WEBSITE,
    "rbb-online": MediaRegionality.WEBSITE,
    "rheinische post": MediaRegionality.REGIONAL,
    "rhein-neckar-zeitung - heidelberger nachrichten": MediaRegionality.REGIONAL,
    "rhein-zeitung koblenz": MediaRegionality.REGIONAL,
    "ruppiner anzeiger": MediaRegionality.REGIONAL,
    "saarbrücker zeitung": MediaRegionality.REGIONAL,
    "sächsische zeitung weisswasser": MediaRegionality.REGIONAL,
    "schweriner volkszeitung": MediaRegionality.REGIONAL,
    "spiegel online": MediaRegionality.WEBSITE,
    "spiegel plus": MediaRegionality.WEBSITE,
    "stuttgarter nachrichten": MediaRegionality.REGIONAL,
    "stuttgarter zeitung": MediaRegionality.REGIONAL,
    "stuttgarter zeitung stadtausgabe": MediaRegionality.REGIONAL,
    "süddeutsche zeitung bayern": MediaRegionality.NATIONAL,  # ?
    "süddeutsche zeitung münchen ost": MediaRegionality.NATIONAL,  # ?
    "südwest presse": MediaRegionality.REGIONAL,
    "superillu": MediaRegionality.NATIONAL,
    "stern": MediaRegionality.NATIONAL,
    "sz magazin": MediaRegionality.NATIONAL,
    "tagesspiegel checkpoint": MediaRegionality.REGIONAL,  # Newsletter
    "tagesspiegel online": MediaRegionality.WEBSITE,
    "thüringer allgemeine erfurt": MediaRegionality.REGIONAL,
    "top magazin berlin": MediaRegionality.REGIONAL,
    "top magazin brandenburg potsdam": MediaRegionality.REGIONAL,
    "twitter": MediaRegionality.WEBSITE,
    "uckermark kurier": MediaRegionality.REGIONAL,
    "uckermark kurier - prenzlauer zeitung": MediaRegionality.REGIONAL,
    "vdi nachrichten": MediaRegionality.NATIONAL,
    "wall street journal online": MediaRegionality.WEBSITE,
    "weilheimer tagblatt": MediaRegionality.REGIONAL,
    "welt am sonntag": MediaRegionality.NATIONAL,
    "welt online": MediaRegionality.WEBSITE,
    "weser-kurier": MediaRegionality.REGIONAL,
    "westdeutsche allgemeine waz": MediaRegionality.REGIONAL,
    "westdeutsche allgemeine waz duisburg": MediaRegionality.REGIONAL,
    "westdeutsche allgemeine waz essen-rüttenscheid": MediaRegionality.REGIONAL,
    "westdeutsche allgemeine waz hattingen": MediaRegionality.REGIONAL,
    "westdeutsche allgemeine waz heiligenhaus, velbert": MediaRegionality.REGIONAL,
    "westdeutsche zeitung": MediaRegionality.REGIONAL,
    "westfälische rundschau": MediaRegionality.REGIONAL,
    "wetterauer zeitung": MediaRegionality.REGIONAL,
    "wirtschaftswoche": MediaRegionality.NATIONAL,
    "wochenspiegel": MediaRegionality.REGIONAL,
    "zeit online": MediaRegionality.WEBSITE
}


class MetaTags(enum.Enum):
    ''' Defines possible MetaTags '''
    UNI = "Universität Potsdam"
    PHIL = "Philosophische Fakultät"
    MATNAT = "Mathematisch-Naturwissenschaftliche Fakultät"
    WISO = "Wirtschafts- und Sozialwissenschaftliche Fakultät"
    HUM = "Humanwissenschaftliche Fakultät"
    DENG = "Digital Engineering Fakultät"
    GEWI = "Fakultät für Gesundheitswissenschaften"
    JURA = "Juristische Fakultät"


meta_tags = {
    "Allgemein": MetaTags.UNI,
    "Allgemeine Hochschultermine": MetaTags.UNI,
    "Alumni": MetaTags.UNI,
    "Anglistik und Amerikanistik": MetaTags.PHIL,
    "Astronomie": MetaTags.MATNAT,
    "Astrophysik": MetaTags.MATNAT,
    "Betriebswirtschaftslehre": MetaTags.WISO,
    "Bildungswissenschaften": MetaTags.HUM,
    "Biochemie": MetaTags.MATNAT,
    "Biologie": MetaTags.MATNAT,
    "Botanischer Garten": MetaTags.UNI,
    "Career Service": MetaTags.UNI,
    "Chancengleichheit": MetaTags.UNI,
    "Chemie": MetaTags.MATNAT,
    "DFG-Research Training Group WIPCAD": MetaTags.WISO,
    "Digital Engineering Fakultät": MetaTags.DENG,
    "Digitalisierung": MetaTags.MATNAT,
    "Earth Surface Dynamics": MetaTags.MATNAT,
    "E-Learning": MetaTags.MATNAT,
    "Erd- und Umweltwissenschaften": MetaTags.MATNAT,
    "Ernährungswissenschaft": MetaTags.MATNAT,
    "Erwachsenenbildung": MetaTags.HUM,
    "Erziehungswissenschaft": MetaTags.HUM,
    "Ethik": MetaTags.PHIL,
    "Fakultät für Gesundheitswissenschaften": MetaTags.GEWI,
    "Forschung": MetaTags.UNI,
    "Forschungsbereich Komplexe Systeme": MetaTags.MATNAT,
    "Forschungsbereich Funktionale Weiche Materie": MetaTags.MATNAT,
    "Forschungsbereich Politik, Verwaltung und Management": MetaTags.WISO,
    "Forschungsinitiative Netzwerk Digitale Geisteswissenschaften": MetaTags.PHIL,
    "Forschungsschwerpunkt Data-Centric Sciences": MetaTags.MATNAT,
    "Forschungsschwerpunkt Erdwissenschaften/Integrierte Erdsystemanalyse": MetaTags.MATNAT,
    "Forschungsschwerpunkt Funktionelle Ökologie und Evolutionsforschung": MetaTags.MATNAT,
    "Forschungsschwerpunkt Kognitionswissenschaften": MetaTags.UNI,
    "Forschungsschwerpunkt Pflanzengenomforschung und Systembiologie": MetaTags.MATNAT,
    "Fundraising": MetaTags.UNI,
    "Geographie": MetaTags.MATNAT,
    "Geologie": MetaTags.MATNAT,
    "Geoökologie": MetaTags.MATNAT,
    "Geowissenschaften": MetaTags.MATNAT,
    "Germanistik": MetaTags.PHIL,
    "Geschichte": MetaTags.PHIL,
    "Gesundheitsmanagement": MetaTags.GEWI,
    "Gesundheitswissenschaften": MetaTags.GEWI,
    "Graduiertenkolleg \"Minor Cosmopolitanisms\"": MetaTags.UNI,
    "Gremientermine": MetaTags.UNI,
    "Grundschulpädagogik": MetaTags.HUM,
    "Gründung und Innovation": MetaTags.UNI,
    "Hochschuldidaktik": MetaTags.PHIL,
    "Hochschulleitung": MetaTags.UNI,
    "Hochschulpolitik": MetaTags.UNI,
    "Hochschulsport": MetaTags.UNI,
    "Hochschulverwaltung": MetaTags.UNI,
    "Humanwissenschaftliche Fakultät": MetaTags.HUM,
    "HumboldtArt": MetaTags.UNI,
    "Informatik": MetaTags.MATNAT,
    "Informationsverarbeitung und Kommunikation": MetaTags.MATNAT,
    "Internationales": MetaTags.UNI,
    "Jüdische Studien": MetaTags.PHIL,
    "Jüdische Theologie": MetaTags.PHIL,
    "Juristische Fakultät": MetaTags.JURA,
    "Klassische Philologie": MetaTags.PHIL,
    "Klima": MetaTags.MATNAT,
    "Kommunikationswissenschaften": MetaTags.UNI,
    "Kulturelle Begegnungsräume": MetaTags.UNI,
    "Kulturwissenschaften": MetaTags.PHIL,
    "Künste und Medien": MetaTags.PHIL,
    "Lebensgestaltung-Ethik-Religionskunde (LER)": MetaTags.PHIL,
    "Lehre": MetaTags.UNI,
    "Lehrerbildung": MetaTags.UNI,
    "Linguistik": MetaTags.HUM,
    "Mathematik": MetaTags.MATNAT,
    "Mathematisch-Naturwissenschaftliche Fakultät": MetaTags.MATNAT,
    "Musikwissenschaften": MetaTags.HUM,
    "Naturwissenschaften": MetaTags.MATNAT,
    "Öffentliches Recht": MetaTags.JURA,
    "Open Science": MetaTags.UNI,
    "Partnerkreis Industrie und Wirtschaft": MetaTags.UNI,
    "Personalia": MetaTags.UNI,
    "Philosophie": MetaTags.PHIL,
    "Philosophische Fakultät": MetaTags.PHIL,
    "Physik": MetaTags.MATNAT,
    "Politik": MetaTags.WISO,
    "Politik und Verwaltung": MetaTags.WISO,
    "Politische Bildung": MetaTags.WISO,
    "Potsdam Graduate School": MetaTags.UNI,
    "Psychologie": MetaTags.HUM,
    "Qualitätsentwicklung in Lehre und Studium": MetaTags.UNI,
    "Rechtswissenschaften": MetaTags.JURA,
    "Religionswissenschaft": MetaTags.PHIL,
    "Romanistik": MetaTags.PHIL,
    "Sachunterricht": MetaTags.HUM,
    "Slavistik": MetaTags.HUM,
    "Sozialwissenschaften": MetaTags.WISO,
    "Soziologie": MetaTags.WISO,
    "Sport- und Gesundheitswissenschaften": MetaTags.HUM,
    "Sprachen und Schlüsselkompetenzen": MetaTags.UNI,
    "Strafrecht": MetaTags.JURA,
    "Studienangelegenheiten / Studium": MetaTags.UNI,
    "Studierendenvertretungen": MetaTags.UNI,
    "Systemakkreditierung": MetaTags.UNI,
    "Theodor-Fontane-Archiv": MetaTags.PHIL,
    "Umweltwissenschaften und Geographie": MetaTags.MATNAT,
    "Uni findet Stadt": MetaTags.UNI,
    "Universitätsbibliothek / Universitätsarchiv": MetaTags.UNI,
    "Universitätsgesellschaft e.V.": MetaTags.UNI,
    "Veranstaltungen": MetaTags.UNI,
    "Verwaltungswissenschaften": MetaTags.WISO,
    "Volkswirtschaftslehre": MetaTags.WISO,
    "Welcome Center Potsdam": MetaTags.UNI,
    "Wirtschaft-Arbeit-Technik": MetaTags.WISO,
    "Wirtschaftswissenschaften": MetaTags.WISO,
    "Weiterbildungen": MetaTags.UNI,
    "Wirtschaftsinformatik": MetaTags.WISO,
    "Wirtschafts- und Sozialwissenschaftliche Fakultät": MetaTags.WISO,
    "Wissenschaftlicher Nachwuchs / Nachwuchsförderung": MetaTags.UNI,
    "Wissens- und Technologietransfer": MetaTags.UNI,
    "Zivilrecht": MetaTags.JURA
}


pressespiegel = {
    "Universität Potsdam": "Pressespiegel",
    "Hochschulen Brandenburg": "Pressespiegel",
    "Hochschulen Berlin": "Pressespiegel",
    "IT im Hochschulbereich": "Pressespiegel",
    "Universität Potsdam in den sozialen Netzen": "Pressespiegel",
}
