""" All Tasks for articles """
import logging
import os
import datetime

from celery import shared_task
from django.utils import timezone

from articles.data_extraction.tasks import extract_information_from_file
from articles.models import Files, Article, Tag, FunctionData
from articles.serializers import write_article_to_db
from one_api.settings_prod import MEDIA_ROOT

logger = logging.getLogger(__name__)


@shared_task
def celery_idle_job(number):
    """ Just a celery task to configure celery right"""
    logger.info("started celery idle task %d", number)
    counting_number = 0
    for i in range(0, 10000):
        counting_number = counting_number + i
    logger.info("idle task %d ist fertig: %d", number, counting_number)


@shared_task
def read_all_media_files():
    """ read all file in the media folder """
    media_dir = os.listdir(MEDIA_ROOT)
    logger.info("read out %i files from media root", len([name for name in media_dir if name.endswith('pdf')]))
    for m_file in list(filter(lambda file_name: file_name.endswith('pdf'), media_dir)):
        if Files.objects.filter(upload_file=m_file).count() == 0:
            file = Files(upload_file=m_file, upload_date=timezone.now())
            file.save()
        elif Files.objects.filter(upload_file=m_file, extraction_complete=False):
            logger.debug("file %s will be re-read", m_file)
            file = Files.objects.get(upload_file=m_file)
            Article.objects.filter(source_file=file).delete()
            extract_information_from_file.delay(file.pk)
        else:
            logger.debug("file %s already exists and was correct extracted in db", m_file)


def generate_article(article_count, upload_date, tag):
    """ generating article """
    file = Files.objects.get(upload_file='wizard_of_oz_faker.pdf')
    input_data = {
        'medium_name': 'Fakemedium',
        'medium_type': 'Zeitschrift',
        'name': 'Fakeartikel',
        'source_file': file,
        'reach': 1000,
        'date_of_publication': upload_date,
        'text': 'Dies ist ein beispielhafter Beispieltext',
        'pages': 2,
        'wrongly_parsed': False,
        'tags': [tag.name],
        'article_count': article_count
    }
    write_article_to_db(**input_data)


def generate_tag(raster_id):
    """ generating new fake tag """
    tag = Tag(name="Fake"+str(raster_id))
    tag.save()


@shared_task
def generate_by_plot():
    """ generating fake articles by function graph """
    if Tag.objects.count() == 0:
        for raster_id in range(0, 3):
            generate_tag(raster_id)

    tags = Tag.objects.all()
    raster_id = 0
    for tag in tags:
        if Files.objects.count() == 0:  # FIXME: specify upload_file GET and insert accordingly
            Files.objects.create(upload_file='wizard_of_oz_faker.pdf', upload_date=datetime.datetime.today())

        start_date = datetime.date(2021, 12, 1)
        qdata = FunctionData.objects.filter(raster=raster_id)
        for qdat in qdata:
            generate_article(qdat.y_data, start_date, tag)
            start_date += datetime.timedelta(days=1)
        raster_id += 1
    # FIXME: hardcoded start date as well as other issues of this origin
